<%
FUNCTION nBinarySearch(sSrchArr, nArrSize, sSrchVal, nSrchFld)
	'**********************************************************
	' Purpose: This function perform a highly efficient binary
	' 			  search of an array for a specific value
	'
	' Parameters: sSrchArr - The array to search
	'				  nArrSize - Number indicating size of array
	'				  sSrchVal - The item to find in the array
	'             nSrchFld - The field to search on
	'
	' Returns: Position in array if found or -1 if not found
	'
	'	Version Date 			SCR/MCR	Author	Description
	'	1.00	  05/09/2001		    	S.Brown	Initial Version
	'**********************************************************
	DIM iLow, iHigh, iMiddle

	'Initialise for search
	iLow  = 0
	iHigh = nArrSize

	DO
		'Find the middle of the section we're looking at now
		iMiddle = CINT(iLow + ((iHigh - iLow) / 2))

		'Is this middle element what we're looking for?
		IF ( CINT(sSrchArr(nSrchFld,iMiddle)) = CINT(sSrchVal) ) THEN
			'If so, return the index of this element
			nBinarySearch = iMiddle
			EXIT FUNCTION
		ELSE
			'Is the middle element less than what we're looking for
			IF ( CINT(sSrchArr(nSrchFld,iMiddle)) < CINT(sSrchVal) ) THEN
				'If so, discard the left half of the array
				iLow = iMiddle + 1
				'IF ( iLow > iHigh ) THEN iLow = iHigh
			ELSE
				'If not, discard the right half of the array
				iHigh = iMiddle - 1
				'IF ( iHigh < iLow ) THEN iHigh = iLow
			END IF
		END IF
	'Keep looping while there are still elements to search
	LOOP WHILE ( iLow <= iHigh)

   'if we reach here the search completed without finding element 
	nBinarySearch = -1
END FUNCTION

FUNCTION nRegularSearch(sSrchArr, nArrSize, sSrchVal, nStrtPos, nSrchFld)
	'**********************************************************
	' Purpose: This function perform a regular top down
	' 			  search of an array for a specific value
	'
	' Parameters: sSrchArr - The array to search
	'				  nArrSize - Number indicating size of array
	'				  sSrchVal - The item to find in the array
	'             nStrtPos - The starting position to search from
	'             nSrchFld - The field to search on
	'
	' Returns: Position in array if found or -1 if not found
	'
	'	Version Date 			SCR/MCR	Author	Description
	'	1.00	  08/02/2002		    	S.Brown	Initial Version
	'**********************************************************
	DIM iFound, iCount

	iFound = -1

	FOR iCount = nStrtPos TO nArrSize
		IF ( CINT(sSrchArr(nSrchFld,iCount)) = CINT(sSrchVal) ) THEN
			iFound = iCount
			EXIT FOR
		END IF
	NEXT

	nRegularSearch = iFound
END FUNCTION

FUNCTION nRegularSearchStr(sSrchArr, nArrSize, sSrchVal, nStrtPos, nSrchFld)
	'**********************************************************
	' Purpose: This function perform a regular top down
	' 			  search of an array for a specific value
	'
	' Parameters: sSrchArr - The array to search
	'				  nArrSize - Number indicating size of array
	'				  sSrchVal - The item to find in the array
	'             nStrtPos - The starting position to search from
	'             nSrchFld - The field to search on
	'
	' Returns: Position in array if found or -1 if not found
	'
	'	Version Date 			SCR/MCR	Author	Description
	'	1.00	  08/02/2002		    	S.Brown	Initial Version
	'**********************************************************
	DIM iFound, iCount

	iFound = -1

	FOR iCount = nStrtPos TO nArrSize
		IF ( UCASE(sSrchArr(nSrchFld,iCount)) = UCASE(sSrchVal) ) THEN
			iFound = iCount
			EXIT FOR
		END IF
	NEXT

	nRegularSearchStr = iFound
END FUNCTION
%>